﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace FirstForm
{
    public partial class Form1 : Form
    {
        private bool drawSquares = false;
        
        public Form1()
        {
            InitializeComponent();
        }

        private void btnShapeSwitch_Click(object sender, EventArgs e)
        {
                drawSquares = !drawSquares;
                ((Button)sender).Text = "Přepnout na " + ((drawSquares) ? "čtverce" : "kruhy");
                txtRadius.Enabled = !drawSquares;
                txtSide.Enabled = drawSquares;
        }

        private void btnGen_Click(object sender, EventArgs e)
        {
            _GenerateGraphics();
        }

        private void _GenerateGraphics()
        {
            if (MessageBox.Show("Opravdu chcete vykreslit útvary?", "Potvrzení", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.No) return;

            int count = 0;
            int size = 0;
            try
            {
                count = Convert.ToInt32(txtCount.Text);
                size = (drawSquares) ? Convert.ToInt32(txtSide.Text) : Convert.ToInt32(txtRadius.Text);
                if ((drawSquares && (size > panel1.Width || size > panel1.Height)) || (!drawSquares && (size * 2 > panel1.Width || size * 2 > panel1.Height)))
                {
                    throw new ArgumentException();
                }
            }
            catch
            {
                MessageBox.Show("Neplatné parametry", "Chyba", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            _Draw(count, size);
        }

        private void _Draw(int count, int size)
        {
            Random r = new Random();

            Graphics g = panel1.CreateGraphics();
            g.Clear(panel1.BackColor);

            if (drawSquares && chckFill.Checked)
            {
                _DrawFilledSquares(g, count, size, r);
            }
            else if (!drawSquares && chckFill.Checked)
            {
                _DrawFilledCircles(g, count, size, r);
            }
            else if (drawSquares && !chckFill.Checked)
            {
                _DrawSquares(g, count, size, r);
            }
            else
            {
                _DrawCircles(g, count, size, r);
            }

            g.Dispose();
        }

        private void _DrawCircles(Graphics g, int count, int size, Random r)
        {
            for (int i = 0; i < count; i++)
            {
                Pen p = new Pen(_GetColor(r));
                g.DrawEllipse(p, r.Next(0, panel1.Width - (size * 2)), r.Next(0, panel1.Height - (size * 2)), size * 2, size * 2); 
                p.Dispose();
            }
        }

        private void _DrawSquares(Graphics g, int count, int size, Random r)
        {
            for (int i = 0; i < count; i++)
            {
                Pen p = new Pen(_GetColor(r));
                g.DrawRectangle(p, r.Next(0, panel1.Width - size), r.Next(0, panel1.Height - size), size, size);
                p.Dispose();
            }
        }

        private void _DrawFilledCircles(Graphics g, int count, int size, Random r)
        {
            for (int i = 0; i < count; i++)
            {
                Brush b = new SolidBrush(_GetColor(r));
                g.FillEllipse(b, r.Next(0, panel1.Width - (size * 2)), r.Next(0, panel1.Height - (size * 2)), size * 2, size * 2);
                b.Dispose();
            }
        }

        private void _DrawFilledSquares(Graphics g, int count, int size, Random r)
        {
            for (int i = 0; i < count; i++)
            {
                Brush b = new SolidBrush(_GetColor(r));
                g.FillRectangle(b, r.Next(0, panel1.Width - size), r.Next(0, panel1.Height - size), size, size);
                b.Dispose();
            }
        }

        private Color _GetColor(Random r)
        {
            return Color.FromArgb(r.Next(0, 256), r.Next(0, 256), r.Next(0, 256));
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (MessageBox.Show("Opravdu chcete skončit?", "Potvrzení", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.No) e.Cancel = true;
        }
    }
}
